@@ -1,9 +1,12 @@
 package config
 
 import (
+	"bytes"
 	"fmt"
 	"net/http"
 	"net/http/httptest"
+	"os"
+	"path/filepath"
 	"testing"
 	"time"
 
@@ -55,6 +58,14 @@ func TestEnvironmentSubstitution(t *testing.T) {
 			contents: "Env var ${MY_VAR} is set, with $MY_VAR syntax and default on this ${MY_VAR1:-Substituted}, no default on this ${MY_VAR2:-NoDefault}",
 			expected: "Env var VALUE is set, with VALUE syntax and default on this Substituted, no default on this VALUE2",
 		},
+		{
+			name: "empty but set",
+			setEnv: func(t *testing.T) {
+				t.Setenv("EMPTY", "")
+			},
+			contents: "Contains ${EMPTY} nothing",
+			expected: "Contains  nothing",
+		},
 		{
 			name:     "Default has special chars",
 			contents: `Not recommended but supported ${MY_VAR:-Default with special chars Supported#$\"}`,
@@ -181,12 +192,18 @@ func TestEnvironmentSubstitutionOldBehavior(t *testing.T) {
 			contents: `${1}`,
 			expected: `${1}`,
 		},
+		{
+			name:     "empty but set",
+			contents: "Contains ${EMPTY} nothing",
+			expected: "Contains  nothing",
+		},
 	}
 
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
 			t.Setenv("VAR", "foobar")
 			t.Setenv("FALLBACK", "default")
+			t.Setenv("EMPTY", "")
 			actual, err := substituteEnvironment([]byte(tt.contents), true)
 			require.NoError(t, err)
 			require.EqualValues(t, tt.expected, string(actual))
@@ -288,6 +305,75 @@ func TestEnvironmentSubstitutionNewBehavior(t *testing.T) {
 	}
 }
 
+func TestParseConfig(t *testing.T) {
+	tests := []struct {
+		name     string
+		setEnv   func(*testing.T)
+		contents string
+		expected string
+		errmsg   string
+	}{
+		{
+			name: "empty var name",
+			contents: `
+# Environment variables can be used anywhere in this config file, simply surround
+# them with ${}. For strings the variable must be within quotes (ie, "${STR_VAR}"),
+# for numbers and booleans they should be plain (ie, ${INT_VAR}, ${BOOL_VAR})Should output ${NOT_SET:-${FALLBACK}}
+`,
+			expected: "\n\n\n\n",
+		},
+		{
+			name: "comment in command (issue #13643)",
+			contents: `
+			[[inputs.exec]]
+			  commands = ["echo \"abc#def\""]
+			`,
+			expected: `
+			[[inputs.exec]]
+			  commands = ["echo \"abc#def\""]
+			`,
+		},
+	}
+
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			if tt.setEnv != nil {
+				tt.setEnv(t)
+			}
+			tbl, err := parseConfig([]byte(tt.contents))
+			if tt.errmsg != "" {
+				require.ErrorContains(t, err, tt.errmsg)
+				return
+			}
+
+			require.NoError(t, err)
+			if len(tt.expected) > 0 {
+				require.EqualValues(t, tt.expected, string(tbl.Data))
+			}
+		})
+	}
+}
+
+func TestRemoveComments(t *testing.T) {
+	// Read expectation
+	expected, err := os.ReadFile(filepath.Join("testdata", "envvar_comments_expected.toml"))
+	require.NoError(t, err)
+
+	// Read the file and remove the comments
+	buf, err := os.ReadFile(filepath.Join("testdata", "envvar_comments.toml"))
+	require.NoError(t, err)
+	removed, err := removeComments(buf)
+	require.NoError(t, err)
+	lines := bytes.Split(removed, []byte{'\n'})
+	for i, line := range lines {
+		lines[i] = bytes.TrimRight(line, " \t")
+	}
+	actual := bytes.Join(lines, []byte{'\n'})
+
+	// Do the comparison
+	require.Equal(t, string(expected), string(actual))
+}
+
 func TestURLRetries3Fails(t *testing.T) {
 	httpLoadConfigRetryInterval = 0 * time.Second
 	responseCounter := 0
