@@ -1,24 +1,27 @@
 package input
 
 import (
+	"errors"
 	"fmt"
+	"testing"
+	"time"
+
 	"github.com/gopcua/opcua/ua"
+	"github.com/stretchr/testify/require"
+
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/config"
 	"github.com/influxdata/telegraf/metric"
 	"github.com/influxdata/telegraf/plugins/common/opcua"
 	"github.com/influxdata/telegraf/testutil"
-	"github.com/stretchr/testify/require"
-	"testing"
-	"time"
 )
 
 func TestTagsSliceToMap(t *testing.T) {
 	m, err := tagsSliceToMap([][]string{{"foo", "bar"}, {"baz", "bat"}})
 	require.NoError(t, err)
 	require.Len(t, m, 2)
-	require.Equal(t, m["foo"], "bar")
-	require.Equal(t, m["baz"], "bat")
+	require.Equal(t, "bar", m["foo"])
+	require.Equal(t, "bat", m["baz"])
 }
 
 func TestTagsSliceToMap_twoStrings(t *testing.T) {
@@ -74,7 +77,7 @@ func TestValidateOPCTags(t *testing.T) {
 					},
 				},
 			},
-			fmt.Errorf("name 'fn' is duplicated (metric name 'mn', tags 't1=v1, t2=v2')"),
+			errors.New(`name "fn" is duplicated (metric name "mn", tags "t1=v1, t2=v2")`),
 		},
 		{
 			"empty tag value not allowed",
@@ -314,7 +317,7 @@ func TestNewNodeMetricMappingIdStrInstantiated(t *testing.T) {
 		TagsSlice:      [][]string{},
 	}, map[string]string{})
 	require.NoError(t, err)
-	require.Equal(t, nmm.idStr, "ns=2;s=h")
+	require.Equal(t, "ns=2;s=h", nmm.idStr)
 }
 
 func TestValidateNodeToAdd(t *testing.T) {
@@ -352,7 +355,7 @@ func TestValidateNodeToAdd(t *testing.T) {
 				}, map[string]string{})
 				return nmm
 			}(),
-			err: fmt.Errorf("empty name in ''"),
+			err: errors.New(`empty name in ""`),
 		},
 		{
 			name:     "empty namespace not allowed",
@@ -382,7 +385,7 @@ func TestValidateNodeToAdd(t *testing.T) {
 				}, map[string]string{})
 				return nmm
 			}(),
-			err: fmt.Errorf("invalid identifier type '' in 'f'"),
+			err: errors.New(`invalid identifier type "" in "f"`),
 		},
 		{
 			name:     "invalid identifier type not allowed",
@@ -397,7 +400,7 @@ func TestValidateNodeToAdd(t *testing.T) {
 				}, map[string]string{})
 				return nmm
 			}(),
-			err: fmt.Errorf("invalid identifier type 'j' in 'f'"),
+			err: errors.New(`invalid identifier type "j" in "f"`),
 		},
 		{
 			name: "duplicate metric not allowed",
@@ -414,7 +417,7 @@ func TestValidateNodeToAdd(t *testing.T) {
 				}, map[string]string{})
 				return nmm
 			}(),
-			err: fmt.Errorf("name 'f' is duplicated (metric name 'testmetric', tags 't1=v1, t2=v2')"),
+			err: errors.New(`name "f" is duplicated (metric name "testmetric", tags "t1=v1, t2=v2")`),
 		},
 		{
 			name:     "identifier type mismatch",
@@ -429,7 +432,7 @@ func TestValidateNodeToAdd(t *testing.T) {
 				}, map[string]string{})
 				return nmm
 			}(),
-			err: fmt.Errorf("identifier type 'i' does not match the type of identifier 'hf'"),
+			err: errors.New(`identifier type "i" does not match the type of identifier "hf"`),
 		},
 	}
 
