@@ -60,7 +60,7 @@ func TestInitPlugin(t *testing.T) {
 	// In case of an error when fetching cpu cores plugin should proceed with execution.
 	require.NoError(t, power.Init())
 	mockServices.fs.AssertCalled(t, "getStringsMatchingPatternOnPath", mock.Anything)
-	require.Equal(t, 0, len(power.msr.getCPUCoresData()))
+	require.Empty(t, power.msr.getCPUCoresData())
 }
 
 func TestParseCPUMetricsConfig(t *testing.T) {
@@ -81,8 +81,8 @@ func TestParseCPUMetricsConfig(t *testing.T) {
 
 	power.CPUMetrics = []string{"cpu_c6_state_residency", "#@$sdkjdfsdf3@", "1pu_c1_state_residency"}
 	power.parseCPUMetricsConfig()
-	require.Equal(t, false, power.cpuC1StateResidency)
-	require.Equal(t, true, power.cpuC6StateResidency)
+	require.False(t, power.cpuC1StateResidency)
+	require.True(t, power.cpuC6StateResidency)
 	disableCoreMetrics(power)
 	verifyCoreMetrics(t, power, false)
 
@@ -127,7 +127,7 @@ func TestGather(t *testing.T) {
 	require.NoError(t, power.Gather(&acc))
 	// Number of global metrics   : 3
 	// Number of per core metrics : 7
-	require.Equal(t, 3*len(packageIDs)+7*len(coreIDs), len(acc.GetTelegrafMetrics()))
+	require.Len(t, acc.GetTelegrafMetrics(), 3*len(packageIDs)+7*len(coreIDs))
 }
 
 func TestAddGlobalMetricsNegative(t *testing.T) {
@@ -142,14 +142,14 @@ func TestAddGlobalMetricsNegative(t *testing.T) {
 		On("retrieveAndCalculateData", mock.Anything).Return(errors.New("error while calculating data")).Times(len(raplDataMap))
 
 	power.addGlobalMetrics(&acc)
-	require.Equal(t, 0, len(acc.GetTelegrafMetrics()))
+	require.Empty(t, acc.GetTelegrafMetrics())
 	mockServices.rapl.AssertNumberOfCalls(t, "retrieveAndCalculateData", len(raplDataMap))
 
 	mockServices.rapl.On("initializeRaplData", mock.Anything).Once().
 		On("getRaplData").Return(make(map[string]*raplData)).Once()
 
 	power.addGlobalMetrics(&acc)
-	require.Equal(t, 0, len(acc.GetTelegrafMetrics()))
+	require.Empty(t, acc.GetTelegrafMetrics())
 	mockServices.rapl.AssertNotCalled(t, "retrieveAndCalculateData")
 
 	mockServices.rapl.On("initializeRaplData", mock.Anything).Once().
@@ -159,7 +159,7 @@ func TestAddGlobalMetricsNegative(t *testing.T) {
 		On("getConstraintMaxPowerWatts", mock.Anything).Return(12313851.5, nil).Twice()
 
 	power.addGlobalMetrics(&acc)
-	require.Equal(t, 3, len(acc.GetTelegrafMetrics()))
+	require.Len(t, acc.GetTelegrafMetrics(), 3)
 }
 
 func TestAddGlobalMetricsPositive(t *testing.T) {
@@ -178,7 +178,7 @@ func TestAddGlobalMetricsPositive(t *testing.T) {
 		On("getCurrentDramPowerConsumption", mock.Anything).Return(dramCurrentEnergy)
 
 	power.addGlobalMetrics(&acc)
-	require.Equal(t, 6, len(acc.GetTelegrafMetrics()))
+	require.Len(t, acc.GetTelegrafMetrics(), 6)
 
 	expectedResults := getGlobalMetrics(maxPower, socketCurrentEnergy, dramCurrentEnergy)
 	for _, test := range expectedResults {
@@ -201,7 +201,7 @@ func TestAddMetricsForSingleCoreNegative(t *testing.T) {
 	power.addMetricsForSingleCore(core, &acc, &wg)
 	wg.Wait()
 
-	require.Equal(t, 0, len(acc.GetTelegrafMetrics()))
+	require.Empty(t, acc.GetTelegrafMetrics())
 }
 
 func TestAddCPUFrequencyMetric(t *testing.T) {
@@ -217,12 +217,12 @@ func TestAddCPUFrequencyMetric(t *testing.T) {
 		Return(float64(0), errors.New("error on reading file")).Once()
 
 	power.addCPUFrequencyMetric(cpuID, &acc)
-	require.Equal(t, 0, len(acc.GetTelegrafMetrics()))
+	require.Empty(t, acc.GetTelegrafMetrics())
 
 	mockServices.msr.On("retrieveCPUFrequencyForCore", mock.Anything).Return(frequency, nil).Once()
 
 	power.addCPUFrequencyMetric(cpuID, &acc)
-	require.Equal(t, 1, len(acc.GetTelegrafMetrics()))
+	require.Len(t, acc.GetTelegrafMetrics(), 1)
 
 	expectedFrequency := roundFloatToNearestTwoDecimalPlaces(frequency)
 	expectedMetric := getPowerCoreMetric("cpu_frequency_mhz", expectedFrequency, coreID, packageID, cpuID)
@@ -257,7 +257,7 @@ func TestReadUncoreFreq(t *testing.T) {
 	power.readUncoreFreq("current", packageID, die, &acc)
 	power.readUncoreFreq("initial", packageID, die, &acc)
 
-	require.Equal(t, 2, len(acc.GetTelegrafMetrics()))
+	require.Len(t, acc.GetTelegrafMetrics(), 2)
 
 	expectedMetric := getPowerUncoreFreqMetric("initial", float64(500), float64(1200), nil, packageID, die)
 	acc.AssertContainsTaggedFields(t, "powerstat_package", expectedMetric.fields, expectedMetric.tags)
@@ -278,7 +278,7 @@ func TestAddCoreCPUTemperatureMetric(t *testing.T) {
 
 	mockServices.msr.On("getCPUCoresData").Return(preparedData).Once()
 	power.addCPUTemperatureMetric(cpuID, &acc)
-	require.Equal(t, 1, len(acc.GetTelegrafMetrics()))
+	require.Len(t, acc.GetTelegrafMetrics(), 1)
 
 	expectedMetric := getPowerCoreMetric("cpu_temperature_celsius", expectedTemp, coreID, packageID, cpuID)
 	acc.AssertContainsTaggedFields(t, "powerstat_core", expectedMetric.fields, expectedMetric.tags)
@@ -297,7 +297,7 @@ func TestAddC6StateResidencyMetric(t *testing.T) {
 
 	mockServices.msr.On("getCPUCoresData").Return(preparedData).Twice()
 	power.addCPUC6StateResidencyMetric(cpuID, &acc)
-	require.Equal(t, 1, len(acc.GetTelegrafMetrics()))
+	require.Len(t, acc.GetTelegrafMetrics(), 1)
 
 	expectedMetric := getPowerCoreMetric("cpu_c6_state_residency_percent", expectedC6, coreID, packageID, cpuID)
 	acc.AssertContainsTaggedFields(t, "powerstat_core", expectedMetric.fields, expectedMetric.tags)
@@ -306,7 +306,7 @@ func TestAddC6StateResidencyMetric(t *testing.T) {
 	preparedData[cpuID].timeStampCounterDelta = 0
 
 	power.addCPUC6StateResidencyMetric(cpuID, &acc)
-	require.Equal(t, 0, len(acc.GetTelegrafMetrics()))
+	require.Empty(t, acc.GetTelegrafMetrics())
 }
 
 func TestAddC0StateResidencyMetric(t *testing.T) {
@@ -323,7 +323,7 @@ func TestAddC0StateResidencyMetric(t *testing.T) {
 	mockServices.msr.On("getCPUCoresData").Return(preparedData).Twice()
 	power.cpuBusyCycles, power.cpuC0StateResidency = true, true
 	power.addCPUC0StateResidencyMetric(cpuID, &acc)
-	require.Equal(t, 2, len(acc.GetTelegrafMetrics()))
+	require.Len(t, acc.GetTelegrafMetrics(), 2)
 
 	expectedMetric := getPowerCoreMetric("cpu_c0_state_residency_percent", expectedBusyCycles, coreID, packageID, cpuID)
 	acc.AssertContainsTaggedFields(t, "powerstat_core", expectedMetric.fields, expectedMetric.tags)
@@ -335,7 +335,7 @@ func TestAddC0StateResidencyMetric(t *testing.T) {
 	acc.ClearMetrics()
 	preparedData[cpuID].timeStampCounterDelta = 0
 	power.addCPUC0StateResidencyMetric(cpuID, &acc)
-	require.Equal(t, 0, len(acc.GetTelegrafMetrics()))
+	require.Empty(t, acc.GetTelegrafMetrics())
 }
 
 func TestAddProcessorBusyFrequencyMetric(t *testing.T) {
@@ -350,12 +350,12 @@ func TestAddProcessorBusyFrequencyMetric(t *testing.T) {
 
 	mockServices.msr.On("getCPUCoresData").Return(preparedData).Twice()
 	power.addCPUBusyFrequencyMetric(cpuID, &acc)
-	require.Equal(t, 1, len(acc.GetTelegrafMetrics()))
+	require.Len(t, acc.GetTelegrafMetrics(), 1)
 
 	acc.ClearMetrics()
 	preparedData[cpuID].mperfDelta = 0
 	power.addCPUBusyFrequencyMetric(cpuID, &acc)
-	require.Equal(t, 0, len(acc.GetTelegrafMetrics()))
+	require.Empty(t, acc.GetTelegrafMetrics())
 }
 
 func TestAddC1StateResidencyMetric(t *testing.T) {
@@ -373,7 +373,7 @@ func TestAddC1StateResidencyMetric(t *testing.T) {
 	mockServices.msr.On("getCPUCoresData").Return(preparedData).Twice()
 
 	power.addCPUC1StateResidencyMetric(cpuID, &acc)
-	require.Equal(t, 1, len(acc.GetTelegrafMetrics()))
+	require.Len(t, acc.GetTelegrafMetrics(), 1)
 
 	expectedMetric := getPowerCoreMetric("cpu_c1_state_residency_percent", expectedC1, coreID, packageID, cpuID)
 	acc.AssertContainsTaggedFields(t, "powerstat_core", expectedMetric.fields, expectedMetric.tags)
@@ -381,7 +381,7 @@ func TestAddC1StateResidencyMetric(t *testing.T) {
 	acc.ClearMetrics()
 	preparedData[cpuID].timeStampCounterDelta = 0
 	power.addCPUC1StateResidencyMetric(cpuID, &acc)
-	require.Equal(t, 0, len(acc.GetTelegrafMetrics()))
+	require.Empty(t, acc.GetTelegrafMetrics())
 }
 
 func TestAddThermalDesignPowerMetric(t *testing.T) {
@@ -395,10 +395,10 @@ func TestAddThermalDesignPowerMetric(t *testing.T) {
 		On("getConstraintMaxPowerWatts", mock.Anything).Return(maxPower, nil).Once()
 
 	power.addThermalDesignPowerMetric(sockets[0], &acc)
-	require.Equal(t, 0, len(acc.GetTelegrafMetrics()))
+	require.Empty(t, acc.GetTelegrafMetrics())
 
 	power.addThermalDesignPowerMetric(sockets[0], &acc)
-	require.Equal(t, 1, len(acc.GetTelegrafMetrics()))
+	require.Len(t, acc.GetTelegrafMetrics(), 1)
 
 	expectedTDP := roundFloatToNearestTwoDecimalPlaces(maxPower)
 	expectedMetric := getPowerGlobalMetric("thermal_design_power_watts", expectedTDP, sockets[0])
@@ -411,7 +411,7 @@ func TestCalculateTurboRatioGroup(t *testing.T) {
 	turboRatioLimitGroups := make(map[int]uint64)
 
 	calculateTurboRatioGroup(coreCounts, msr, turboRatioLimitGroups)
-	require.Equal(t, 8, len(turboRatioLimitGroups))
+	require.Len(t, turboRatioLimitGroups, 8)
 	require.Equal(t, uint64(100), turboRatioLimitGroups[1])
 	require.Equal(t, uint64(200), turboRatioLimitGroups[2])
 	require.Equal(t, uint64(300), turboRatioLimitGroups[3])
@@ -423,7 +423,7 @@ func TestCalculateTurboRatioGroup(t *testing.T) {
 
 	coreCounts = uint64(0x100e0c0a08060402)
 	calculateTurboRatioGroup(coreCounts, msr, turboRatioLimitGroups)
-	require.Equal(t, 16, len(turboRatioLimitGroups))
+	require.Len(t, turboRatioLimitGroups, 16)
 	require.Equal(t, uint64(100), turboRatioLimitGroups[1])
 	require.Equal(t, uint64(100), turboRatioLimitGroups[2])
 	require.Equal(t, uint64(200), turboRatioLimitGroups[3])
@@ -443,14 +443,14 @@ func TestCalculateTurboRatioGroup(t *testing.T) {
 	coreCounts = uint64(0x1211)
 	msr = uint64(0xfffe)
 	calculateTurboRatioGroup(coreCounts, msr, turboRatioLimitGroups)
-	require.Equal(t, 18, len(turboRatioLimitGroups))
+	require.Len(t, turboRatioLimitGroups, 18)
 	require.Equal(t, uint64(25400), turboRatioLimitGroups[17])
 	require.Equal(t, uint64(25500), turboRatioLimitGroups[18])
 
 	coreCounts = uint64(0x1201)
 	msr = uint64(0x0202)
 	calculateTurboRatioGroup(coreCounts, msr, turboRatioLimitGroups)
-	require.Equal(t, 18, len(turboRatioLimitGroups))
+	require.Len(t, turboRatioLimitGroups, 18)
 	require.Equal(t, uint64(200), turboRatioLimitGroups[1])
 	require.Equal(t, uint64(200), turboRatioLimitGroups[2])
 	require.Equal(t, uint64(200), turboRatioLimitGroups[3])
@@ -474,7 +474,7 @@ func TestCalculateTurboRatioGroup(t *testing.T) {
 	msr = uint64(0xfffe)
 	turboRatioLimitGroups = make(map[int]uint64)
 	calculateTurboRatioGroup(coreCounts, msr, turboRatioLimitGroups)
-	require.Equal(t, 2, len(turboRatioLimitGroups))
+	require.Len(t, turboRatioLimitGroups, 2)
 	require.Equal(t, uint64(25400), turboRatioLimitGroups[17])
 	require.Equal(t, uint64(25500), turboRatioLimitGroups[18])
 }
@@ -827,7 +827,7 @@ func TestAddCPUBaseFreq(t *testing.T) {
 			p.addCPUBaseFreq(tt.socketID, &acc)
 			actual := acc.GetTelegrafMetrics()
 			if !tt.metricExpected {
-				require.Len(t, actual, 0)
+				require.Empty(t, actual)
 				return
 			}
 
