@@ -70,11 +70,11 @@ func TestInit(t *testing.T) {
 			name:   "default config",
 			plugin: &KafkaConsumer{},
 			check: func(t *testing.T, plugin *KafkaConsumer) {
-				require.Equal(t, plugin.ConsumerGroup, defaultConsumerGroup)
-				require.Equal(t, plugin.MaxUndeliveredMessages, defaultMaxUndeliveredMessages)
-				require.Equal(t, plugin.config.ClientID, "Telegraf")
-				require.Equal(t, plugin.config.Consumer.Offsets.Initial, sarama.OffsetOldest)
-				require.Equal(t, plugin.config.Consumer.MaxProcessingTime, 100*time.Millisecond)
+				require.Equal(t, defaultConsumerGroup, plugin.ConsumerGroup)
+				require.Equal(t, defaultMaxUndeliveredMessages, plugin.MaxUndeliveredMessages)
+				require.Equal(t, "Telegraf", plugin.config.ClientID)
+				require.Equal(t, sarama.OffsetOldest, plugin.config.Consumer.Offsets.Initial)
+				require.Equal(t, 100*time.Millisecond, plugin.config.Consumer.MaxProcessingTime)
 			},
 		},
 		{
@@ -114,7 +114,7 @@ func TestInit(t *testing.T) {
 				Log: testutil.Logger{},
 			},
 			check: func(t *testing.T, plugin *KafkaConsumer) {
-				require.Equal(t, plugin.config.ClientID, "custom")
+				require.Equal(t, "custom", plugin.config.ClientID)
 			},
 		},
 		{
@@ -124,7 +124,7 @@ func TestInit(t *testing.T) {
 				Log:    testutil.Logger{},
 			},
 			check: func(t *testing.T, plugin *KafkaConsumer) {
-				require.Equal(t, plugin.config.Consumer.Offsets.Initial, sarama.OffsetNewest)
+				require.Equal(t, sarama.OffsetNewest, plugin.config.Consumer.Offsets.Initial)
 			},
 		},
 		{
@@ -197,7 +197,7 @@ func TestInit(t *testing.T) {
 				Log:               testutil.Logger{},
 			},
 			check: func(t *testing.T, plugin *KafkaConsumer) {
-				require.Equal(t, plugin.config.Consumer.MaxProcessingTime, 1000*time.Millisecond)
+				require.Equal(t, 1000*time.Millisecond, plugin.config.Consumer.MaxProcessingTime)
 			},
 		},
 	}
@@ -293,11 +293,11 @@ func (c *FakeConsumerGroupClaim) Messages() <-chan *sarama.ConsumerMessage {
 
 func TestConsumerGroupHandler_Lifecycle(t *testing.T) {
 	acc := &testutil.Accumulator{}
+
 	parser := value.Parser{
 		MetricName: "cpu",
 		DataType:   "int",
 	}
-	require.NoError(t, parser.Init())
 	cg := NewConsumerGroupHandler(acc, 1, &parser, testutil.Logger{})
 
 	ctx, cancel := context.WithCancel(context.Background())
@@ -669,7 +669,6 @@ func TestExponentialBackoffDefault(t *testing.T) {
 	parser := &influx.Parser{}
 	require.NoError(t, parser.Init())
 	input.SetParser(parser)
-
 	require.NoError(t, input.Init())
 
 	// We don't need to start the plugin here since we're only testing
