@@ -5,6 +5,9 @@ import (
 	"errors"
 	"fmt"
 	"hash/maphash"
+
+	"github.com/influxdata/telegraf"
+	"github.com/influxdata/telegraf/models"
 )
 
 //go:embed sample_request.conf
@@ -34,6 +37,7 @@ type requestDefinition struct {
 type ConfigurationPerRequest struct {
 	Requests    []requestDefinition `toml:"request"`
 	workarounds ModbusWorkarounds
+	logger      telegraf.Logger
 }
 
 func (c *ConfigurationPerRequest) SampleConfigPart() string {
@@ -64,7 +68,19 @@ func (c *ConfigurationPerRequest) Check() error {
 		}
 		// Check for valid optimization
 		switch def.Optimization {
-		case "", "none", "shrink", "rearrange", "aggressive":
+		case "", "none", "shrink", "rearrange":
+		case "aggressive":
+			models.PrintOptionValueDeprecationNotice(
+				telegraf.Warn,
+				"inputs.modbus",
+				"optimization",
+				"aggressive",
+				telegraf.DeprecationInfo{
+					Since:     "1.28.2",
+					RemovalIn: "1.30.0",
+					Notice:    `use "max_insert" instead`,
+				},
+			)
 		case "max_insert":
 			switch def.RegisterType {
 			case "coil":
@@ -191,6 +207,7 @@ func (c *ConfigurationPerRequest) Process() (map[byte]requestSet, error) {
 			MaxExtraRegisters: def.MaxExtraRegisters,
 			Optimization:      def.Optimization,
 			Tags:              def.Tags,
+			Log:               c.logger,
 		}
 		switch def.RegisterType {
 		case "coil":
