@@ -37,7 +37,9 @@ type Postgresql struct {
 type query []struct {
 	Sqlquery    string
 	Script      string
-	Version     int
+	Version     int  `deprecated:"1.28.0;use minVersion to specify minimal DB version this query supports"`
+	MinVersion  int  `toml:"min_version"`
+	MaxVersion  int  `toml:"max_version"`
 	Withdbname  bool `deprecated:"1.22.4;use the sqlquery option to specify database to use"`
 	Tagvalue    string
 	Measurement string
@@ -59,6 +61,9 @@ func (p *Postgresql) Init() error {
 				return err
 			}
 		}
+		if p.Query[i].MinVersion == 0 {
+			p.Query[i].MinVersion = p.Query[i].Version
+		}
 	}
 	p.Service.IsPgBouncer = !p.PreparedStatements
 	return nil
@@ -120,7 +125,9 @@ func (p *Postgresql) Gather(acc telegraf.Accumulator) error {
 		}
 		sqlQuery += queryAddon
 
-		if p.Query[i].Version <= dbVersion {
+		maxVer := p.Query[i].MaxVersion
+
+		if p.Query[i].MinVersion <= dbVersion && (maxVer == 0 || maxVer > dbVersion) {
 			p.gatherMetricsFromQuery(acc, sqlQuery, p.Query[i].Tagvalue, p.Query[i].Timestamp, measName)
 		}
 	}
@@ -186,8 +193,12 @@ func (p *Postgresql) accRow(measName string, row scanner, acc telegraf.Accumulat
 		columnVars = append(columnVars, columnMap[columns[i]])
 	}
 
+	if tagAddress, err = p.SanitizedAddress(); err != nil {
+		return err
+	}
+
 	// deconstruct array of variables and send to Scan
-	if err = row.Scan(columnVars...); err != nil {
+	if err := row.Scan(columnVars...); err != nil {
 		return err
 	}
 
@@ -199,18 +210,22 @@ func (p *Postgresql) accRow(measName string, row scanner, acc telegraf.Accumulat
 				return err
 			}
 		default:
-			if _, err := dbname.WriteString("postgres"); err != nil {
+			database, err := p.GetConnectDatabase(tagAddress)
+			if err != nil {
+				return err
+			}
+			if _, err := dbname.WriteString(database); err != nil {
 				return err
 			}
 		}
 	} else {
-		if _, err := dbname.WriteString("postgres"); err != nil {
+		database, err := p.GetConnectDatabase(tagAddress)
+		if err != nil {
+			return err
+		}
+		if _, err := dbname.WriteString(database); err != nil {
 			return err
 		}
-	}
-
-	if tagAddress, err = p.SanitizedAddress(); err != nil {
-		return err
 	}
 
 	// Process the additional tags
