@@ -11,7 +11,6 @@ import (
 
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/plugins/inputs"
-	"github.com/influxdata/telegraf/plugins/parsers"
 	"github.com/influxdata/telegraf/selfstat"
 )
 
@@ -49,7 +48,7 @@ type UDPListener struct {
 	// malformed tracks the number of malformed packets
 	malformed int
 
-	parser parsers.Parser
+	parser telegraf.Parser
 
 	// Keep the accumulator in this struct
 	acc telegraf.Accumulator
@@ -83,7 +82,7 @@ func (u *UDPListener) Gather(_ telegraf.Accumulator) error {
 	return nil
 }
 
-func (u *UDPListener) SetParser(parser parsers.Parser) {
+func (u *UDPListener) SetParser(parser telegraf.Parser) {
 	u.parser = parser
 }
 
