@@ -1,7 +1,7 @@
 package github
 
 import (
-	"fmt"
+	"strconv"
 	"time"
 
 	"github.com/influxdata/telegraf"
@@ -95,9 +95,9 @@ func (s CommitCommentEvent) NewMetric() telegraf.Metric {
 	t := map[string]string{
 		"event":      event,
 		"repository": s.Repository.Repository,
-		"private":    fmt.Sprintf("%v", s.Repository.Private),
+		"private":    strconv.FormatBool(s.Repository.Private),
 		"user":       s.Sender.User,
-		"admin":      fmt.Sprintf("%v", s.Sender.Admin),
+		"admin":      strconv.FormatBool(s.Sender.Admin),
 	}
 	f := map[string]interface{}{
 		"stars":   s.Repository.Stars,
@@ -106,7 +106,7 @@ func (s CommitCommentEvent) NewMetric() telegraf.Metric {
 		"commit":  s.Comment.Commit,
 		"comment": s.Comment.Body,
 	}
-	m, _ := metric.New(meas, t, f, time.Now())
+	m := metric.New(meas, t, f, time.Now())
 	return m
 }
 
@@ -122,9 +122,9 @@ func (s CreateEvent) NewMetric() telegraf.Metric {
 	t := map[string]string{
 		"event":      event,
 		"repository": s.Repository.Repository,
-		"private":    fmt.Sprintf("%v", s.Repository.Private),
+		"private":    strconv.FormatBool(s.Repository.Private),
 		"user":       s.Sender.User,
-		"admin":      fmt.Sprintf("%v", s.Sender.Admin),
+		"admin":      strconv.FormatBool(s.Sender.Admin),
 	}
 	f := map[string]interface{}{
 		"stars":   s.Repository.Stars,
@@ -133,7 +133,7 @@ func (s CreateEvent) NewMetric() telegraf.Metric {
 		"ref":     s.Ref,
 		"refType": s.RefType,
 	}
-	m, _ := metric.New(meas, t, f, time.Now())
+	m := metric.New(meas, t, f, time.Now())
 	return m
 }
 
@@ -149,9 +149,9 @@ func (s DeleteEvent) NewMetric() telegraf.Metric {
 	t := map[string]string{
 		"event":      event,
 		"repository": s.Repository.Repository,
-		"private":    fmt.Sprintf("%v", s.Repository.Private),
+		"private":    strconv.FormatBool(s.Repository.Private),
 		"user":       s.Sender.User,
-		"admin":      fmt.Sprintf("%v", s.Sender.Admin),
+		"admin":      strconv.FormatBool(s.Sender.Admin),
 	}
 	f := map[string]interface{}{
 		"stars":   s.Repository.Stars,
@@ -160,7 +160,7 @@ func (s DeleteEvent) NewMetric() telegraf.Metric {
 		"ref":     s.Ref,
 		"refType": s.RefType,
 	}
-	m, _ := metric.New(meas, t, f, time.Now())
+	m := metric.New(meas, t, f, time.Now())
 	return m
 }
 
@@ -175,9 +175,9 @@ func (s DeploymentEvent) NewMetric() telegraf.Metric {
 	t := map[string]string{
 		"event":      event,
 		"repository": s.Repository.Repository,
-		"private":    fmt.Sprintf("%v", s.Repository.Private),
+		"private":    strconv.FormatBool(s.Repository.Private),
 		"user":       s.Sender.User,
-		"admin":      fmt.Sprintf("%v", s.Sender.Admin),
+		"admin":      strconv.FormatBool(s.Sender.Admin),
 	}
 	f := map[string]interface{}{
 		"stars":       s.Repository.Stars,
@@ -188,7 +188,7 @@ func (s DeploymentEvent) NewMetric() telegraf.Metric {
 		"environment": s.Deployment.Environment,
 		"description": s.Deployment.Description,
 	}
-	m, _ := metric.New(meas, t, f, time.Now())
+	m := metric.New(meas, t, f, time.Now())
 	return m
 }
 
@@ -204,9 +204,9 @@ func (s DeploymentStatusEvent) NewMetric() telegraf.Metric {
 	t := map[string]string{
 		"event":      event,
 		"repository": s.Repository.Repository,
-		"private":    fmt.Sprintf("%v", s.Repository.Private),
+		"private":    strconv.FormatBool(s.Repository.Private),
 		"user":       s.Sender.User,
-		"admin":      fmt.Sprintf("%v", s.Sender.Admin),
+		"admin":      strconv.FormatBool(s.Sender.Admin),
 	}
 	f := map[string]interface{}{
 		"stars":          s.Repository.Stars,
@@ -219,7 +219,7 @@ func (s DeploymentStatusEvent) NewMetric() telegraf.Metric {
 		"depState":       s.DeploymentStatus.State,
 		"depDescription": s.DeploymentStatus.Description,
 	}
-	m, _ := metric.New(meas, t, f, time.Now())
+	m := metric.New(meas, t, f, time.Now())
 	return m
 }
 
@@ -234,9 +234,9 @@ func (s ForkEvent) NewMetric() telegraf.Metric {
 	t := map[string]string{
 		"event":      event,
 		"repository": s.Repository.Repository,
-		"private":    fmt.Sprintf("%v", s.Repository.Private),
+		"private":    strconv.FormatBool(s.Repository.Private),
 		"user":       s.Sender.User,
-		"admin":      fmt.Sprintf("%v", s.Sender.Admin),
+		"admin":      strconv.FormatBool(s.Sender.Admin),
 	}
 	f := map[string]interface{}{
 		"stars":  s.Repository.Stars,
@@ -244,7 +244,7 @@ func (s ForkEvent) NewMetric() telegraf.Metric {
 		"issues": s.Repository.Issues,
 		"fork":   s.Forkee.Repository,
 	}
-	m, _ := metric.New(meas, t, f, time.Now())
+	m := metric.New(meas, t, f, time.Now())
 	return m
 }
 
@@ -260,16 +260,16 @@ func (s GollumEvent) NewMetric() telegraf.Metric {
 	t := map[string]string{
 		"event":      event,
 		"repository": s.Repository.Repository,
-		"private":    fmt.Sprintf("%v", s.Repository.Private),
+		"private":    strconv.FormatBool(s.Repository.Private),
 		"user":       s.Sender.User,
-		"admin":      fmt.Sprintf("%v", s.Sender.Admin),
+		"admin":      strconv.FormatBool(s.Sender.Admin),
 	}
 	f := map[string]interface{}{
 		"stars":  s.Repository.Stars,
 		"forks":  s.Repository.Forks,
 		"issues": s.Repository.Issues,
 	}
-	m, _ := metric.New(meas, t, f, time.Now())
+	m := metric.New(meas, t, f, time.Now())
 	return m
 }
 
@@ -285,10 +285,10 @@ func (s IssueCommentEvent) NewMetric() telegraf.Metric {
 	t := map[string]string{
 		"event":      event,
 		"repository": s.Repository.Repository,
-		"private":    fmt.Sprintf("%v", s.Repository.Private),
+		"private":    strconv.FormatBool(s.Repository.Private),
 		"user":       s.Sender.User,
-		"admin":      fmt.Sprintf("%v", s.Sender.Admin),
-		"issue":      fmt.Sprintf("%v", s.Issue.Number),
+		"admin":      strconv.FormatBool(s.Sender.Admin),
+		"issue":      strconv.Itoa(s.Issue.Number),
 	}
 	f := map[string]interface{}{
 		"stars":    s.Repository.Stars,
@@ -298,7 +298,7 @@ func (s IssueCommentEvent) NewMetric() telegraf.Metric {
 		"comments": s.Issue.Comments,
 		"body":     s.Comment.Body,
 	}
-	m, _ := metric.New(meas, t, f, time.Now())
+	m := metric.New(meas, t, f, time.Now())
 	return m
 }
 
@@ -314,10 +314,10 @@ func (s IssuesEvent) NewMetric() telegraf.Metric {
 	t := map[string]string{
 		"event":      event,
 		"repository": s.Repository.Repository,
-		"private":    fmt.Sprintf("%v", s.Repository.Private),
+		"private":    strconv.FormatBool(s.Repository.Private),
 		"user":       s.Sender.User,
-		"admin":      fmt.Sprintf("%v", s.Sender.Admin),
-		"issue":      fmt.Sprintf("%v", s.Issue.Number),
+		"admin":      strconv.FormatBool(s.Sender.Admin),
+		"issue":      strconv.Itoa(s.Issue.Number),
 		"action":     s.Action,
 	}
 	f := map[string]interface{}{
@@ -327,7 +327,7 @@ func (s IssuesEvent) NewMetric() telegraf.Metric {
 		"title":    s.Issue.Title,
 		"comments": s.Issue.Comments,
 	}
-	m, _ := metric.New(meas, t, f, time.Now())
+	m := metric.New(meas, t, f, time.Now())
 	return m
 }
 
@@ -342,9 +342,9 @@ func (s MemberEvent) NewMetric() telegraf.Metric {
 	t := map[string]string{
 		"event":      event,
 		"repository": s.Repository.Repository,
-		"private":    fmt.Sprintf("%v", s.Repository.Private),
+		"private":    strconv.FormatBool(s.Repository.Private),
 		"user":       s.Sender.User,
-		"admin":      fmt.Sprintf("%v", s.Sender.Admin),
+		"admin":      strconv.FormatBool(s.Sender.Admin),
 	}
 	f := map[string]interface{}{
 		"stars":           s.Repository.Stars,
@@ -353,7 +353,7 @@ func (s MemberEvent) NewMetric() telegraf.Metric {
 		"newMember":       s.Member.User,
 		"newMemberStatus": s.Member.Admin,
 	}
-	m, _ := metric.New(meas, t, f, time.Now())
+	m := metric.New(meas, t, f, time.Now())
 	return m
 }
 
@@ -369,14 +369,14 @@ func (s MembershipEvent) NewMetric() telegraf.Metric {
 	t := map[string]string{
 		"event":  event,
 		"user":   s.Sender.User,
-		"admin":  fmt.Sprintf("%v", s.Sender.Admin),
+		"admin":  strconv.FormatBool(s.Sender.Admin),
 		"action": s.Action,
 	}
 	f := map[string]interface{}{
 		"newMember":       s.Member.User,
 		"newMemberStatus": s.Member.Admin,
 	}
-	m, _ := metric.New(meas, t, f, time.Now())
+	m := metric.New(meas, t, f, time.Now())
 	return m
 }
 
@@ -390,16 +390,16 @@ func (s PageBuildEvent) NewMetric() telegraf.Metric {
 	t := map[string]string{
 		"event":      event,
 		"repository": s.Repository.Repository,
-		"private":    fmt.Sprintf("%v", s.Repository.Private),
+		"private":    strconv.FormatBool(s.Repository.Private),
 		"user":       s.Sender.User,
-		"admin":      fmt.Sprintf("%v", s.Sender.Admin),
+		"admin":      strconv.FormatBool(s.Sender.Admin),
 	}
 	f := map[string]interface{}{
 		"stars":  s.Repository.Stars,
 		"forks":  s.Repository.Forks,
 		"issues": s.Repository.Issues,
 	}
-	m, _ := metric.New(meas, t, f, time.Now())
+	m := metric.New(meas, t, f, time.Now())
 	return m
 }
 
@@ -413,16 +413,16 @@ func (s PublicEvent) NewMetric() telegraf.Metric {
 	t := map[string]string{
 		"event":      event,
 		"repository": s.Repository.Repository,
-		"private":    fmt.Sprintf("%v", s.Repository.Private),
+		"private":    strconv.FormatBool(s.Repository.Private),
 		"user":       s.Sender.User,
-		"admin":      fmt.Sprintf("%v", s.Sender.Admin),
+		"admin":      strconv.FormatBool(s.Sender.Admin),
 	}
 	f := map[string]interface{}{
 		"stars":  s.Repository.Stars,
 		"forks":  s.Repository.Forks,
 		"issues": s.Repository.Issues,
 	}
-	m, _ := metric.New(meas, t, f, time.Now())
+	m := metric.New(meas, t, f, time.Now())
 	return m
 }
 
@@ -439,10 +439,10 @@ func (s PullRequestEvent) NewMetric() telegraf.Metric {
 		"event":      event,
 		"action":     s.Action,
 		"repository": s.Repository.Repository,
-		"private":    fmt.Sprintf("%v", s.Repository.Private),
+		"private":    strconv.FormatBool(s.Repository.Private),
 		"user":       s.Sender.User,
-		"admin":      fmt.Sprintf("%v", s.Sender.Admin),
-		"prNumber":   fmt.Sprintf("%v", s.PullRequest.Number),
+		"admin":      strconv.FormatBool(s.Sender.Admin),
+		"prNumber":   strconv.Itoa(s.PullRequest.Number),
 	}
 	f := map[string]interface{}{
 		"stars":        s.Repository.Stars,
@@ -456,7 +456,7 @@ func (s PullRequestEvent) NewMetric() telegraf.Metric {
 		"deletions":    s.PullRequest.Deletions,
 		"changedFiles": s.PullRequest.ChangedFiles,
 	}
-	m, _ := metric.New(meas, t, f, time.Now())
+	m := metric.New(meas, t, f, time.Now())
 	return m
 }
 
@@ -472,10 +472,10 @@ func (s PullRequestReviewCommentEvent) NewMetric() telegraf.Metric {
 	t := map[string]string{
 		"event":      event,
 		"repository": s.Repository.Repository,
-		"private":    fmt.Sprintf("%v", s.Repository.Private),
+		"private":    strconv.FormatBool(s.Repository.Private),
 		"user":       s.Sender.User,
-		"admin":      fmt.Sprintf("%v", s.Sender.Admin),
-		"prNumber":   fmt.Sprintf("%v", s.PullRequest.Number),
+		"admin":      strconv.FormatBool(s.Sender.Admin),
+		"prNumber":   strconv.Itoa(s.PullRequest.Number),
 	}
 	f := map[string]interface{}{
 		"stars":        s.Repository.Stars,
@@ -491,7 +491,7 @@ func (s PullRequestReviewCommentEvent) NewMetric() telegraf.Metric {
 		"commentFile":  s.Comment.File,
 		"comment":      s.Comment.Comment,
 	}
-	m, _ := metric.New(meas, t, f, time.Now())
+	m := metric.New(meas, t, f, time.Now())
 	return m
 }
 
@@ -508,9 +508,9 @@ func (s PushEvent) NewMetric() telegraf.Metric {
 	t := map[string]string{
 		"event":      event,
 		"repository": s.Repository.Repository,
-		"private":    fmt.Sprintf("%v", s.Repository.Private),
+		"private":    strconv.FormatBool(s.Repository.Private),
 		"user":       s.Sender.User,
-		"admin":      fmt.Sprintf("%v", s.Sender.Admin),
+		"admin":      strconv.FormatBool(s.Sender.Admin),
 	}
 	f := map[string]interface{}{
 		"stars":  s.Repository.Stars,
@@ -520,7 +520,7 @@ func (s PushEvent) NewMetric() telegraf.Metric {
 		"before": s.Before,
 		"after":  s.After,
 	}
-	m, _ := metric.New(meas, t, f, time.Now())
+	m := metric.New(meas, t, f, time.Now())
 	return m
 }
 
@@ -535,9 +535,9 @@ func (s ReleaseEvent) NewMetric() telegraf.Metric {
 	t := map[string]string{
 		"event":      event,
 		"repository": s.Repository.Repository,
-		"private":    fmt.Sprintf("%v", s.Repository.Private),
+		"private":    strconv.FormatBool(s.Repository.Private),
 		"user":       s.Sender.User,
-		"admin":      fmt.Sprintf("%v", s.Sender.Admin),
+		"admin":      strconv.FormatBool(s.Sender.Admin),
 	}
 	f := map[string]interface{}{
 		"stars":   s.Repository.Stars,
@@ -545,7 +545,7 @@ func (s ReleaseEvent) NewMetric() telegraf.Metric {
 		"issues":  s.Repository.Issues,
 		"tagName": s.Release.TagName,
 	}
-	m, _ := metric.New(meas, t, f, time.Now())
+	m := metric.New(meas, t, f, time.Now())
 	return m
 }
 
@@ -559,16 +559,16 @@ func (s RepositoryEvent) NewMetric() telegraf.Metric {
 	t := map[string]string{
 		"event":      event,
 		"repository": s.Repository.Repository,
-		"private":    fmt.Sprintf("%v", s.Repository.Private),
+		"private":    strconv.FormatBool(s.Repository.Private),
 		"user":       s.Sender.User,
-		"admin":      fmt.Sprintf("%v", s.Sender.Admin),
+		"admin":      strconv.FormatBool(s.Sender.Admin),
 	}
 	f := map[string]interface{}{
 		"stars":  s.Repository.Stars,
 		"forks":  s.Repository.Forks,
 		"issues": s.Repository.Issues,
 	}
-	m, _ := metric.New(meas, t, f, time.Now())
+	m := metric.New(meas, t, f, time.Now())
 	return m
 }
 
@@ -584,9 +584,9 @@ func (s StatusEvent) NewMetric() telegraf.Metric {
 	t := map[string]string{
 		"event":      event,
 		"repository": s.Repository.Repository,
-		"private":    fmt.Sprintf("%v", s.Repository.Private),
+		"private":    strconv.FormatBool(s.Repository.Private),
 		"user":       s.Sender.User,
-		"admin":      fmt.Sprintf("%v", s.Sender.Admin),
+		"admin":      strconv.FormatBool(s.Sender.Admin),
 	}
 	f := map[string]interface{}{
 		"stars":  s.Repository.Stars,
@@ -595,7 +595,7 @@ func (s StatusEvent) NewMetric() telegraf.Metric {
 		"commit": s.Commit,
 		"state":  s.State,
 	}
-	m, _ := metric.New(meas, t, f, time.Now())
+	m := metric.New(meas, t, f, time.Now())
 	return m
 }
 
@@ -610,9 +610,9 @@ func (s TeamAddEvent) NewMetric() telegraf.Metric {
 	t := map[string]string{
 		"event":      event,
 		"repository": s.Repository.Repository,
-		"private":    fmt.Sprintf("%v", s.Repository.Private),
+		"private":    strconv.FormatBool(s.Repository.Private),
 		"user":       s.Sender.User,
-		"admin":      fmt.Sprintf("%v", s.Sender.Admin),
+		"admin":      strconv.FormatBool(s.Sender.Admin),
 	}
 	f := map[string]interface{}{
 		"stars":    s.Repository.Stars,
@@ -620,7 +620,7 @@ func (s TeamAddEvent) NewMetric() telegraf.Metric {
 		"issues":   s.Repository.Issues,
 		"teamName": s.Team.Name,
 	}
-	m, _ := metric.New(meas, t, f, time.Now())
+	m := metric.New(meas, t, f, time.Now())
 	return m
 }
 
@@ -634,15 +634,15 @@ func (s WatchEvent) NewMetric() telegraf.Metric {
 	t := map[string]string{
 		"event":      event,
 		"repository": s.Repository.Repository,
-		"private":    fmt.Sprintf("%v", s.Repository.Private),
+		"private":    strconv.FormatBool(s.Repository.Private),
 		"user":       s.Sender.User,
-		"admin":      fmt.Sprintf("%v", s.Sender.Admin),
+		"admin":      strconv.FormatBool(s.Sender.Admin),
 	}
 	f := map[string]interface{}{
 		"stars":  s.Repository.Stars,
 		"forks":  s.Repository.Forks,
 		"issues": s.Repository.Issues,
 	}
-	m, _ := metric.New(meas, t, f, time.Now())
+	m := metric.New(meas, t, f, time.Now())
 	return m
 }
