@@ -4,9 +4,10 @@ import (
 	"testing"
 	"time"
 
-	"github.com/influxdata/telegraf/config"
 	amqp "github.com/rabbitmq/amqp091-go"
 	"github.com/stretchr/testify/require"
+
+	"github.com/influxdata/telegraf/config"
 )
 
 type MockClient struct {
@@ -63,8 +64,8 @@ func TestConnect(t *testing.T) {
 				require.Equal(t, []string{DefaultURL}, cfg.brokers)
 				require.Equal(t, "", cfg.exchange)
 				require.Equal(t, "topic", cfg.exchangeType)
-				require.Equal(t, false, cfg.exchangePassive)
-				require.Equal(t, true, cfg.exchangeDurable)
+				require.False(t, cfg.exchangePassive)
+				require.True(t, cfg.exchangeDurable)
 				require.Equal(t, amqp.Table(nil), cfg.exchangeArguments)
 				require.Equal(t, amqp.Table{
 					"database":         DefaultDatabase,
