@@ -127,11 +127,11 @@ func (c *CloudWatchLogs) Init() error {
 
 	c.logDatKey = lsSplitArray[0]
 	c.logDataSource = lsSplitArray[1]
-	c.Log.Debugf("Log data: key '%s', source '%s'...", c.logDatKey, c.logDataSource)
+	c.Log.Debugf("Log data: key %q, source %q...", c.logDatKey, c.logDataSource)
 
 	if c.lsSource == "" {
 		c.lsSource = c.LogStream
-		c.Log.Debugf("Log stream '%s'...", c.lsSource)
+		c.Log.Debugf("Log stream %q...", c.lsSource)
 	}
 
 	return nil
@@ -341,8 +341,7 @@ func (c *CloudWatchLogs) Write(metrics []telegraf.Metric) error {
 	// Sorting out log events by TS and sending them to cloud watch logs
 	for logStream, elem := range c.ls {
 		for index, batch := range elem.messageBatches {
-			if len(batch.logEvents) == 0 { //can't push empty batch
-				//c.Log.Warnf("Empty batch detected, skipping...")
+			if len(batch.logEvents) == 0 {
 				continue
 			}
 			//Sorting
@@ -376,7 +375,7 @@ func (c *CloudWatchLogs) Write(metrics []telegraf.Metric) error {
 					continue
 				}
 			} else {
-				putLogEvents.SequenceToken = &elem.sequenceToken
+				putLogEvents.SequenceToken = &c.ls[logStream].sequenceToken
 			}
 
 			//Upload log events
