@@ -36,7 +36,7 @@ type Client interface {
 
 // InfluxDB struct is the primary data structure for the plugin
 type InfluxDB struct {
-	URL                       string            `toml:"url" deprecated:"0.1.9;2.0.0;use 'urls' instead"`
+	URL                       string            `toml:"url" deprecated:"0.1.9;1.30.0;use 'urls' instead"`
 	URLs                      []string          `toml:"urls"`
 	Username                  config.Secret     `toml:"username"`
 	Password                  config.Secret     `toml:"password"`
@@ -169,10 +169,15 @@ func (i *InfluxDB) Write(metrics []telegraf.Metric) error {
 }
 
 func (i *InfluxDB) udpClient(address *url.URL) (Client, error) {
+	serializer := &influx.Serializer{UintSupport: i.InfluxUintSupport}
+	if err := serializer.Init(); err != nil {
+		return nil, err
+	}
+
 	udpConfig := &UDPConfig{
 		URL:            address,
 		MaxPayloadSize: int(i.UDPPayload),
-		Serializer:     i.newSerializer(),
+		Serializer:     serializer,
 		Log:            i.Log,
 	}
 
@@ -190,6 +195,11 @@ func (i *InfluxDB) httpClient(ctx context.Context, address *url.URL, proxy *url.
 		return nil, err
 	}
 
+	serializer := &influx.Serializer{UintSupport: i.InfluxUintSupport}
+	if err := serializer.Init(); err != nil {
+		return nil, err
+	}
+
 	httpConfig := &HTTPConfig{
 		URL:                       address,
 		Timeout:                   time.Duration(i.Timeout),
@@ -208,7 +218,7 @@ func (i *InfluxDB) httpClient(ctx context.Context, address *url.URL, proxy *url.
 		RetentionPolicyTag:        i.RetentionPolicyTag,
 		ExcludeRetentionPolicyTag: i.ExcludeRetentionPolicyTag,
 		Consistency:               i.WriteConsistency,
-		Serializer:                i.newSerializer(),
+		Serializer:                serializer,
 		Log:                       i.Log,
 	}
 
@@ -228,15 +238,6 @@ func (i *InfluxDB) httpClient(ctx context.Context, address *url.URL, proxy *url.
 	return c, nil
 }
 
-func (i *InfluxDB) newSerializer() *influx.Serializer {
-	serializer := influx.NewSerializer()
-	if i.InfluxUintSupport {
-		serializer.SetFieldTypeSupport(influx.UintSupport)
-	}
-
-	return serializer
-}
-
 func init() {
 	outputs.Add("influxdb", func() telegraf.Output {
 		return &InfluxDB{
