@@ -86,8 +86,8 @@ func TestConnectAndWriteIntegrationSCRAMAuth(t *testing.T) {
 				Dsn: fmt.Sprintf("mongodb://%s:%s/admin",
 					container.Address, container.Ports[servicePort]),
 				AuthenticationType: "SCRAM",
-				Username:           "root",
-				Password:           "changeme",
+				Username:           config.NewSecret([]byte("root")),
+				Password:           config.NewSecret([]byte("changeme")),
 				MetricDatabase:     "telegraf_test",
 				MetricGranularity:  "seconds",
 			},
@@ -101,8 +101,8 @@ func TestConnectAndWriteIntegrationSCRAMAuth(t *testing.T) {
 				Dsn: fmt.Sprintf("mongodb://%s:%s/admin",
 					container.Address, container.Ports[servicePort]),
 				AuthenticationType:  "SCRAM",
-				Username:            "root",
-				Password:            "root",
+				Username:            config.NewSecret([]byte("root")),
+				Password:            config.NewSecret([]byte("root")),
 				MetricDatabase:      "telegraf_test",
 				MetricGranularity:   "seconds",
 				ServerSelectTimeout: config.Duration(time.Duration(5) * time.Second),
@@ -380,7 +380,7 @@ func TestConfiguration(t *testing.T) {
 			plugin: &MongoDB{
 				Dsn:                "mongodb://localhost:27017",
 				AuthenticationType: "SCRAM",
-				Password:           "somerandompasswordthatwontwork",
+				Password:           config.NewSecret([]byte("somerandompasswordthatwontwork")),
 				MetricDatabase:     "telegraf_test",
 				MetricGranularity:  "seconds",
 			},
@@ -390,7 +390,7 @@ func TestConfiguration(t *testing.T) {
 			plugin: &MongoDB{
 				Dsn:                "mongodb://localhost:27017",
 				AuthenticationType: "SCRAM",
-				Username:           "somerandomusernamethatwontwork",
+				Username:           config.NewSecret([]byte("somerandomusernamethatwontwork")),
 				MetricDatabase:     "telegraf_test",
 				MetricGranularity:  "seconds",
 			},
