@@ -3,6 +3,7 @@ package timestream
 import (
 	"context"
 	"fmt"
+	"math"
 	"reflect"
 	"sort"
 	"strconv"
@@ -95,7 +96,7 @@ func TestConnectValidatesConfigParameters(t *testing.T) {
 		MeasureNameForMultiMeasureRecords: "multi-measure-name",
 		Log:                               testutil.Logger{},
 	}
-	require.Nil(t, validConfigMultiMeasureMultiTableMode.Connect())
+	require.NoError(t, validConfigMultiMeasureMultiTableMode.Connect())
 
 	invalidConfigMultiMeasureMultiTableMode := Timestream{
 		DatabaseName:           tsDbName,
@@ -115,7 +116,7 @@ func TestConnectValidatesConfigParameters(t *testing.T) {
 		// measurement name (from telegraf metric) is used as multi-measure name in TS
 		Log: testutil.Logger{},
 	}
-	require.Nil(t, validConfigMultiMeasureSingleTableMode.Connect())
+	require.NoError(t, validConfigMultiMeasureSingleTableMode.Connect())
 
 	invalidConfigMultiMeasureSingleTableMode := Timestream{
 		DatabaseName:                      tsDbName,
@@ -136,7 +137,7 @@ func TestConnectValidatesConfigParameters(t *testing.T) {
 		MappingMode:  MappingModeMultiTable,
 		Log:          testutil.Logger{},
 	}
-	require.Nil(t, validMappingModeMultiTable.Connect())
+	require.NoError(t, validMappingModeMultiTable.Connect())
 
 	singleTableNameWithMultiTable := Timestream{
 		DatabaseName:    tsDbName,
@@ -179,7 +180,7 @@ func TestConnectValidatesConfigParameters(t *testing.T) {
 		SingleTableDimensionNameForTelegrafMeasurementName: testSingleTableDim,
 		Log: testutil.Logger{},
 	}
-	require.Nil(t, validConfigurationMappingModeSingleTable.Connect())
+	require.NoError(t, validConfigurationMappingModeSingleTable.Connect())
 
 	// create table arguments
 	createTableNoMagneticRetention := Timestream{
@@ -209,7 +210,7 @@ func TestConnectValidatesConfigParameters(t *testing.T) {
 		CreateTableMemoryStoreRetentionPeriodInHours:  3,
 		Log: testutil.Logger{},
 	}
-	require.Nil(t, createTableValid.Connect())
+	require.NoError(t, createTableValid.Connect())
 
 	// describe table on start arguments
 	describeTableInvoked := Timestream{
@@ -262,20 +263,20 @@ func TestWriteMultiMeasuresSingleTableMode(t *testing.T) {
 	// validate multi-record generation
 	result := plugin.TransformMetrics(inputs)
 	// 'inputs' has a total of 101 metrics transformed to 2 writeRecord calls to TS
-	require.Equal(t, 2, len(result), "Expected 2 WriteRecordsInput requests")
+	require.Len(t, result, 2, "Expected 2 WriteRecordsInput requests")
 
 	var transformedRecords []types.Record
 	for _, r := range result {
 		transformedRecords = append(transformedRecords, r.Records...)
 		// Assert that we use measure name from input
-		require.Equal(t, *r.Records[0].MeasureName, "multi_measure_name")
+		require.Equal(t, "multi_measure_name", *r.Records[0].MeasureName)
 	}
 	// Expected 101 records
-	require.Equal(t, recordCount+1, len(transformedRecords), "Expected 101 records after transforming")
+	require.Len(t, transformedRecords, recordCount+1, "Expected 101 records after transforming")
 	// validate write to TS
 	err := plugin.Write(inputs)
-	require.Nil(t, err, "Write to Timestream failed")
-	require.Equal(t, mockClient.WriteRecordsRequestCount, 2, "Expected 2 WriteRecords calls")
+	require.NoError(t, err, "Write to Timestream failed")
+	require.Equal(t, 2, mockClient.WriteRecordsRequestCount, "Expected 2 WriteRecords calls")
 }
 
 func TestWriteMultiMeasuresMultiTableMode(t *testing.T) {
@@ -315,22 +316,22 @@ func TestWriteMultiMeasuresMultiTableMode(t *testing.T) {
 
 	// validate config correctness
 	err := plugin.Connect()
-	require.Nil(t, err, "Invalid configuration")
+	require.NoError(t, err, "Invalid configuration")
 
 	// validate multi-record generation
 	result := plugin.TransformMetrics(inputs)
 	// 'inputs' has a total of 101 metrics transformed to 2 writeRecord calls to TS
-	require.Equal(t, 1, len(result), "Expected 1 WriteRecordsInput requests")
+	require.Len(t, result, 1, "Expected 1 WriteRecordsInput requests")
 
 	// Assert that we use measure name from config
-	require.Equal(t, *result[0].Records[0].MeasureName, "config-multi-measure-name")
+	require.Equal(t, "config-multi-measure-name", *result[0].Records[0].MeasureName)
 
 	var transformedRecords []types.Record
 	for _, r := range result {
 		transformedRecords = append(transformedRecords, r.Records...)
 	}
 	// Expected 100 records
-	require.Equal(t, recordCount, len(transformedRecords), "Expected 100 records after transforming")
+	require.Len(t, transformedRecords, recordCount, "Expected 100 records after transforming")
 
 	for _, input := range inputs {
 		fmt.Println("Input", input)
@@ -340,8 +341,8 @@ func TestWriteMultiMeasuresMultiTableMode(t *testing.T) {
 
 	// validate successful write to TS
 	err = plugin.Write(inputs)
-	require.Nil(t, err, "Write to Timestream failed")
-	require.Equal(t, mockClient.WriteRecordsRequestCount, 1, "Expected 1 WriteRecords call")
+	require.NoError(t, err, "Write to Timestream failed")
+	require.Equal(t, 1, mockClient.WriteRecordsRequestCount, "Expected 1 WriteRecords call")
 }
 
 func TestBuildMultiMeasuresInSingleAndMultiTableMode(t *testing.T) {
@@ -381,6 +382,24 @@ func TestBuildMultiMeasuresInSingleAndMultiTableMode(t *testing.T) {
 		time1,
 	)
 
+	input5 := testutil.MustMetric(
+		metricName1,
+		map[string]string{"tag5": "value5"},
+		map[string]interface{}{
+			"measureMaxUint64": uint64(math.MaxUint64),
+		},
+		time1,
+	)
+
+	input6 := testutil.MustMetric(
+		metricName1,
+		map[string]string{"tag6": "value6"},
+		map[string]interface{}{
+			"measureSmallUint64": uint64(123456),
+		},
+		time1,
+	)
+
 	expectedResultMultiTable := buildExpectedMultiRecords("config-multi-measure-name", metricName1)
 
 	plugin := Timestream{
@@ -393,11 +412,11 @@ func TestBuildMultiMeasuresInSingleAndMultiTableMode(t *testing.T) {
 
 	// validate config correctness
 	err := plugin.Connect()
-	require.Nil(t, err, "Invalid configuration")
+	require.NoError(t, err, "Invalid configuration")
 
 	// validate multi-record generation with MappingModeMultiTable
-	result := plugin.TransformMetrics([]telegraf.Metric{input1, input2, input3, input4})
-	require.Equal(t, 1, len(result), "Expected 1 WriteRecordsInput requests")
+	result := plugin.TransformMetrics([]telegraf.Metric{input1, input2, input3, input4, input5, input6})
+	require.Len(t, result, 1, "Expected 1 WriteRecordsInput requests")
 
 	require.EqualValues(t, result[0], expectedResultMultiTable)
 
@@ -416,13 +435,13 @@ func TestBuildMultiMeasuresInSingleAndMultiTableMode(t *testing.T) {
 
 	// validate config correctness
 	err = plugin.Connect()
-	require.Nil(t, err, "Invalid configuration")
+	require.NoError(t, err, "Invalid configuration")
 
 	expectedResultSingleTable := buildExpectedMultiRecords(metricName1, "singleTableName")
 
 	// validate multi-record generation with MappingModeSingleTable
-	result = plugin.TransformMetrics([]telegraf.Metric{input1, input2, input3, input4})
-	require.Equal(t, 1, len(result), "Expected 1 WriteRecordsInput requests")
+	result = plugin.TransformMetrics([]telegraf.Metric{input1, input2, input3, input4, input5, input6})
+	require.Len(t, result, 1, "Expected 1 WriteRecordsInput requests")
 
 	require.EqualValues(t, result[0], expectedResultSingleTable)
 
@@ -473,6 +492,28 @@ func buildExpectedMultiRecords(multiMeasureName string, tableName string) *times
 
 	recordsMultiTableMode = append(recordsMultiTableMode, recordBool...)
 
+	recordMaxUint64 := buildMultiRecords([]SimpleInput{
+		{
+			t:             time1Epoch,
+			tableName:     metricName1,
+			dimensions:    map[string]string{"tag5": "value5"},
+			measureValues: map[string]string{"measureMaxUint64": "9223372036854775807"},
+		},
+	}, multiMeasureName, types.MeasureValueTypeBigint)
+
+	recordsMultiTableMode = append(recordsMultiTableMode, recordMaxUint64...)
+
+	recordUint64 := buildMultiRecords([]SimpleInput{
+		{
+			t:             time1Epoch,
+			tableName:     metricName1,
+			dimensions:    map[string]string{"tag6": "value6"},
+			measureValues: map[string]string{"measureSmallUint64": "123456"},
+		},
+	}, multiMeasureName, types.MeasureValueTypeBigint)
+
+	recordsMultiTableMode = append(recordsMultiTableMode, recordUint64...)
+
 	expectedResultMultiTable := &timestreamwrite.WriteRecordsInput{
 		DatabaseName:     aws.String(tsDbName),
 		TableName:        aws.String(tableName),
@@ -532,7 +573,7 @@ func TestThrottlingErrorIsReturnedToTelegraf(t *testing.T) {
 
 	err := plugin.Write([]telegraf.Metric{input})
 
-	require.NotNil(t, err, "Expected an error to be returned to Telegraf, "+
+	require.Error(t, err, "Expected an error to be returned to Telegraf, "+
 		"so that the write will be retried by Telegraf later.")
 }
 
@@ -558,7 +599,7 @@ func TestRejectedRecordsErrorResultsInMetricsBeingSkipped(t *testing.T) {
 
 	err := plugin.Write([]telegraf.Metric{input})
 
-	require.Nil(t, err, "Expected to silently swallow the RejectedRecordsException, "+
+	require.NoError(t, err, "Expected to silently swallow the RejectedRecordsException, "+
 		"as retrying this error doesn't make sense.")
 }
 func TestWriteWhenRequestsGreaterThanMaxWriteGoRoutinesCount(t *testing.T) {
@@ -596,8 +637,8 @@ func TestWriteWhenRequestsGreaterThanMaxWriteGoRoutinesCount(t *testing.T) {
 	}
 
 	err := plugin.Write(inputs)
-	require.Nil(t, err, "Expected to write without any errors ")
-	require.Equal(t, mockClient.WriteRecordsRequestCount, maxWriteRecordsCalls, "Expected 5 calls to WriteRecords")
+	require.NoError(t, err, "Expected to write without any errors ")
+	require.Equal(t, maxWriteRecordsCalls, mockClient.WriteRecordsRequestCount, "Expected 5 calls to WriteRecords")
 }
 
 func TestWriteWhenRequestsLesserThanMaxWriteGoRoutinesCount(t *testing.T) {
@@ -635,8 +676,8 @@ func TestWriteWhenRequestsLesserThanMaxWriteGoRoutinesCount(t *testing.T) {
 	}
 
 	err := plugin.Write(inputs)
-	require.Nil(t, err, "Expected to write without any errors ")
-	require.Equal(t, mockClient.WriteRecordsRequestCount, maxWriteRecordsCalls, "Expected 5 calls to WriteRecords")
+	require.NoError(t, err, "Expected to write without any errors ")
+	require.Equal(t, maxWriteRecordsCalls, mockClient.WriteRecordsRequestCount, "Expected 5 calls to WriteRecords")
 }
 
 func TestTransformMetricsSkipEmptyMetric(t *testing.T) {
@@ -1180,7 +1221,7 @@ func TestCustomEndpoint(t *testing.T) {
 
 	// validate config correctness
 	err := plugin.Connect()
-	require.Nil(t, err, "Invalid configuration")
+	require.NoError(t, err, "Invalid configuration")
 	// Check customURL is used
 	require.Equal(t, plugin.EndpointURL, customEndpoint)
 }
