@@ -9,16 +9,15 @@ import (
 	"time"
 
 	"github.com/google/go-cmp/cmp"
+	"github.com/influxdata/toml"
+	"github.com/stretchr/testify/require"
+
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/config"
 	"github.com/influxdata/telegraf/plugins/inputs"
 	"github.com/influxdata/telegraf/plugins/inputs/file"
 	"github.com/influxdata/telegraf/plugins/parsers/influx"
-	"github.com/influxdata/telegraf/plugins/parsers/temporary/xpath"
 	"github.com/influxdata/telegraf/testutil"
-	"github.com/influxdata/toml"
-
-	"github.com/stretchr/testify/require"
 )
 
 const invalidXML = `
@@ -111,14 +110,14 @@ func TestParseInvalidXML(t *testing.T) {
 	var tests = []struct {
 		name          string
 		input         string
-		configs       []xpath.Config
+		configs       []Config
 		defaultTags   map[string]string
 		expectedError string
 	}{
 		{
 			name:  "invalid XML (missing close tag)",
 			input: invalidXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					MetricQuery: "test",
 					Timestamp:   "/Device_1/Timestamp_unix",
@@ -150,14 +149,14 @@ func TestInvalidTypeQueriesFail(t *testing.T) {
 	var tests = []struct {
 		name          string
 		input         string
-		configs       []xpath.Config
+		configs       []Config
 		defaultTags   map[string]string
 		expectedError string
 	}{
 		{
 			name:  "invalid field (int) type",
 			input: singleMetricValuesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix",
 					FieldsInt: map[string]string{
@@ -191,14 +190,14 @@ func TestInvalidTypeQueries(t *testing.T) {
 	var tests = []struct {
 		name        string
 		input       string
-		configs     []xpath.Config
+		configs     []Config
 		defaultTags map[string]string
 		expected    telegraf.Metric
 	}{
 		{
 			name:  "invalid field type (number)",
 			input: singleMetricValuesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix",
 					Fields: map[string]string{
@@ -219,7 +218,7 @@ func TestInvalidTypeQueries(t *testing.T) {
 		{
 			name:  "invalid field type (boolean)",
 			input: singleMetricValuesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix",
 					Fields: map[string]string{
@@ -261,14 +260,14 @@ func TestParseTimestamps(t *testing.T) {
 	var tests = []struct {
 		name        string
 		input       string
-		configs     []xpath.Config
+		configs     []Config
 		defaultTags map[string]string
 		expected    telegraf.Metric
 	}{
 		{
 			name:  "parse timestamp (no fmt)",
 			input: singleMetricValuesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix",
 				},
@@ -284,7 +283,7 @@ func TestParseTimestamps(t *testing.T) {
 		{
 			name:  "parse timestamp (unix)",
 			input: singleMetricValuesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Timestamp:    "/Device_1/Timestamp_unix",
 					TimestampFmt: "unix",
@@ -301,7 +300,7 @@ func TestParseTimestamps(t *testing.T) {
 		{
 			name:  "parse timestamp (unix_ms)",
 			input: singleMetricValuesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Timestamp:    "/Device_1/Timestamp_unix_ms",
 					TimestampFmt: "unix_ms",
@@ -318,7 +317,7 @@ func TestParseTimestamps(t *testing.T) {
 		{
 			name:  "parse timestamp (unix_us)",
 			input: singleMetricValuesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Timestamp:    "/Device_1/Timestamp_unix_us",
 					TimestampFmt: "unix_us",
@@ -335,7 +334,7 @@ func TestParseTimestamps(t *testing.T) {
 		{
 			name:  "parse timestamp (unix_us)",
 			input: singleMetricValuesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Timestamp:    "/Device_1/Timestamp_unix_ns",
 					TimestampFmt: "unix_ns",
@@ -352,7 +351,7 @@ func TestParseTimestamps(t *testing.T) {
 		{
 			name:  "parse timestamp (RFC3339)",
 			input: singleMetricValuesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Timestamp:    "/Device_1/Timestamp_iso",
 					TimestampFmt: "2006-01-02T15:04:05Z",
@@ -390,14 +389,14 @@ func TestParseSingleValues(t *testing.T) {
 	var tests = []struct {
 		name        string
 		input       string
-		configs     []xpath.Config
+		configs     []Config
 		defaultTags map[string]string
 		expected    telegraf.Metric
 	}{
 		{
 			name:  "parse scalar values as string fields",
 			input: singleMetricValuesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix",
 					Fields: map[string]string{
@@ -424,7 +423,7 @@ func TestParseSingleValues(t *testing.T) {
 		{
 			name:  "parse scalar values as typed fields (w/o int)",
 			input: singleMetricValuesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix",
 					Fields: map[string]string{
@@ -451,7 +450,7 @@ func TestParseSingleValues(t *testing.T) {
 		{
 			name:  "parse values as typed fields (w/ int)",
 			input: singleMetricValuesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix",
 					Fields: map[string]string{
@@ -480,7 +479,7 @@ func TestParseSingleValues(t *testing.T) {
 		{
 			name:  "parse substring values",
 			input: singleMetricValuesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix",
 					Fields: map[string]string{
@@ -503,7 +502,7 @@ func TestParseSingleValues(t *testing.T) {
 		{
 			name:  "parse substring values (typed)",
 			input: singleMetricValuesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix",
 					Fields: map[string]string{
@@ -526,7 +525,7 @@ func TestParseSingleValues(t *testing.T) {
 		{
 			name:  "parse substring values (typed int)",
 			input: singleMetricValuesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix",
 					FieldsInt: map[string]string{
@@ -549,7 +548,7 @@ func TestParseSingleValues(t *testing.T) {
 		{
 			name:  "parse tags",
 			input: singleMetricValuesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix",
 					Tags: map[string]string{
@@ -593,14 +592,14 @@ func TestParseSingleAttributes(t *testing.T) {
 	var tests = []struct {
 		name        string
 		input       string
-		configs     []xpath.Config
+		configs     []Config
 		defaultTags map[string]string
 		expected    telegraf.Metric
 	}{
 		{
 			name:  "parse attr timestamp (unix)",
 			input: singleMetricAttributesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix/@value",
 				},
@@ -616,7 +615,7 @@ func TestParseSingleAttributes(t *testing.T) {
 		{
 			name:  "parse attr timestamp (RFC3339)",
 			input: singleMetricAttributesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Timestamp:    "/Device_1/Timestamp_iso/@value",
 					TimestampFmt: "2006-01-02T15:04:05Z",
@@ -633,7 +632,7 @@ func TestParseSingleAttributes(t *testing.T) {
 		{
 			name:  "parse attr as string fields",
 			input: singleMetricAttributesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix/@value",
 					Fields: map[string]string{
@@ -660,7 +659,7 @@ func TestParseSingleAttributes(t *testing.T) {
 		{
 			name:  "parse attr as typed fields (w/o int)",
 			input: singleMetricAttributesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix/@value",
 					Fields: map[string]string{
@@ -687,7 +686,7 @@ func TestParseSingleAttributes(t *testing.T) {
 		{
 			name:  "parse attr as typed fields (w/ int)",
 			input: singleMetricAttributesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix/@value",
 					Fields: map[string]string{
@@ -716,7 +715,7 @@ func TestParseSingleAttributes(t *testing.T) {
 		{
 			name:  "parse attr substring",
 			input: singleMetricAttributesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix/@value",
 					Fields: map[string]string{
@@ -737,7 +736,7 @@ func TestParseSingleAttributes(t *testing.T) {
 		{
 			name:  "parse attr tags",
 			input: singleMetricAttributesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix/@value",
 					Tags: map[string]string{
@@ -760,7 +759,7 @@ func TestParseSingleAttributes(t *testing.T) {
 		{
 			name:  "parse attr bool",
 			input: singleMetricAttributesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix/@value",
 					Fields: map[string]string{
@@ -802,14 +801,14 @@ func TestParseMultiValues(t *testing.T) {
 	var tests = []struct {
 		name        string
 		input       string
-		configs     []xpath.Config
+		configs     []Config
 		defaultTags map[string]string
 		expected    telegraf.Metric
 	}{
 		{
 			name:  "select values (float)",
 			input: singleMetricMultiValuesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Timestamp: "/Timestamp/@value",
 					Fields: map[string]string{
@@ -840,7 +839,7 @@ func TestParseMultiValues(t *testing.T) {
 		{
 			name:  "select values (int)",
 			input: singleMetricMultiValuesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Timestamp: "/Timestamp/@value",
 					FieldsInt: map[string]string{
@@ -892,14 +891,14 @@ func TestParseMultiNodes(t *testing.T) {
 	var tests = []struct {
 		name        string
 		input       string
-		configs     []xpath.Config
+		configs     []Config
 		defaultTags map[string]string
 		expected    []telegraf.Metric
 	}{
 		{
 			name:  "select all devices",
 			input: multipleNodesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Selection: "/Device",
 					Timestamp: "/Timestamp/@value",
@@ -1009,14 +1008,14 @@ func TestParseMetricQuery(t *testing.T) {
 	var tests = []struct {
 		name        string
 		input       string
-		configs     []xpath.Config
+		configs     []Config
 		defaultTags map[string]string
 		expected    telegraf.Metric
 	}{
 		{
 			name:  "parse metric name query",
 			input: metricNameQueryXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					MetricQuery: "name(/Device_1/Metric/@*[1])",
 					Timestamp:   "/Device_1/Timestamp_unix",
@@ -1038,7 +1037,7 @@ func TestParseMetricQuery(t *testing.T) {
 		{
 			name:  "parse metric name constant",
 			input: metricNameQueryXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					MetricQuery: "'the_metric'",
 					Timestamp:   "/Device_1/Timestamp_unix",
@@ -1081,13 +1080,13 @@ func TestParseErrors(t *testing.T) {
 	var tests = []struct {
 		name     string
 		input    string
-		configs  []xpath.Config
+		configs  []Config
 		expected string
 	}{
 		{
 			name:  "string metric name query",
 			input: metricNameQueryXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					MetricQuery: "arbitrary",
 					Timestamp:   "/Device_1/Timestamp_unix",
@@ -1121,12 +1120,12 @@ func TestEmptySelection(t *testing.T) {
 	var tests = []struct {
 		name    string
 		input   string
-		configs []xpath.Config
+		configs []Config
 	}{
 		{
 			name:  "empty path",
 			input: multipleNodesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Selection: "/Device/NonExisting",
 					Fields:    map[string]string{"value": "number(Value)"},
@@ -1138,7 +1137,7 @@ func TestEmptySelection(t *testing.T) {
 		{
 			name:  "empty pattern",
 			input: multipleNodesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Selection: "//NonExisting",
 					Fields:    map[string]string{"value": "number(Value)"},
@@ -1150,7 +1149,7 @@ func TestEmptySelection(t *testing.T) {
 		{
 			name:  "empty axis",
 			input: multipleNodesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Selection: "/Device/child::NonExisting",
 					Fields:    map[string]string{"value": "number(Value)"},
@@ -1162,7 +1161,7 @@ func TestEmptySelection(t *testing.T) {
 		{
 			name:  "empty predicate",
 			input: multipleNodesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Selection: "/Device[@NonExisting=true]",
 					Fields:    map[string]string{"value": "number(Value)"},
@@ -1185,7 +1184,7 @@ func TestEmptySelection(t *testing.T) {
 
 			_, err := parser.Parse([]byte(tt.input))
 			require.Error(t, err)
-			require.Equal(t, err.Error(), "cannot parse with empty selection node")
+			require.Equal(t, "cannot parse with empty selection node", err.Error())
 		})
 	}
 }
@@ -1194,12 +1193,12 @@ func TestEmptySelectionAllowed(t *testing.T) {
 	var tests = []struct {
 		name    string
 		input   string
-		configs []xpath.Config
+		configs []Config
 	}{
 		{
 			name:  "empty path",
 			input: multipleNodesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Selection: "/Device/NonExisting",
 					Fields:    map[string]string{"value": "number(Value)"},
@@ -1211,7 +1210,7 @@ func TestEmptySelectionAllowed(t *testing.T) {
 		{
 			name:  "empty pattern",
 			input: multipleNodesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Selection: "//NonExisting",
 					Fields:    map[string]string{"value": "number(Value)"},
@@ -1223,7 +1222,7 @@ func TestEmptySelectionAllowed(t *testing.T) {
 		{
 			name:  "empty axis",
 			input: multipleNodesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Selection: "/Device/child::NonExisting",
 					Fields:    map[string]string{"value": "number(Value)"},
@@ -1235,7 +1234,7 @@ func TestEmptySelectionAllowed(t *testing.T) {
 		{
 			name:  "empty predicate",
 			input: multipleNodesXML,
-			configs: []xpath.Config{
+			configs: []Config{
 				{
 					Selection: "/Device[@NonExisting=true]",
 					Fields:    map[string]string{"value": "number(Value)"},
@@ -1321,7 +1320,7 @@ func TestTestCases(t *testing.T) {
 			require.Len(t, input, 1)
 
 			filefields := strings.Fields(input[0])
-			require.GreaterOrEqual(t, len(filefields), 1)
+			require.NotEmpty(t, filefields)
 			datafile := filepath.FromSlash(filefields[0])
 			fileformat := ""
 			if len(filefields) > 1 {
@@ -1360,7 +1359,7 @@ func TestTestCases(t *testing.T) {
 				Format:              fileformat,
 				ProtobufMessageDef:  pbmsgdef,
 				ProtobufMessageType: pbmsgtype,
-				Configs:             []xpath.Config{*cfg},
+				Configs:             []Config{*cfg},
 				Log:                 testutil.Logger{Name: "parsers.xml"},
 			}
 			require.NoError(t, parser.Init())
@@ -1368,6 +1367,7 @@ func TestTestCases(t *testing.T) {
 			if len(expectedErrors) == 0 {
 				require.NoError(t, err)
 			}
+
 			// If no timestamp is given we cannot test it. So use the one of the output
 			if cfg.Timestamp == "" {
 				testutil.RequireMetricsEqual(t, expectedOutputs, outputs, testutil.IgnoreTime())
@@ -1386,7 +1386,7 @@ func TestProtobufImporting(t *testing.T) {
 		ProtobufMessageDef:  "person.proto",
 		ProtobufMessageType: "importtest.Person",
 		ProtobufImportPaths: []string{"testcases/protos"},
-		Configs:             []xpath.Config{},
+		Configs:             []Config{},
 		Log:                 testutil.Logger{Name: "parsers.protobuf"},
 	}
 	require.NoError(t, parser.Init())
@@ -1477,7 +1477,7 @@ func TestMultipleConfigs(t *testing.T) {
 	}
 }
 
-func loadTestConfiguration(filename string) (*xpath.Config, []string, error) {
+func loadTestConfiguration(filename string) (*Config, []string, error) {
 	buf, err := os.ReadFile(filename)
 	if err != nil {
 		return nil, nil, err
@@ -1490,7 +1490,7 @@ func loadTestConfiguration(filename string) (*xpath.Config, []string, error) {
 			header = append(header, line)
 		}
 	}
-	cfg := xpath.Config{}
+	cfg := Config{}
 	err = toml.Unmarshal(buf, &cfg)
 	return &cfg, header, err
 }
