@@ -232,9 +232,7 @@ def apply(metric):
 				}
 			}
 
-			err = plugin.Stop()
-			require.NoError(t, err)
-
+			plugin.Stop()
 			testutil.RequireMetricsEqual(t, tt.expected, acc.GetTelegrafMetrics())
 		})
 	}
@@ -2576,9 +2574,7 @@ def apply(metric):
 				}
 			}
 
-			err = plugin.Stop()
-			require.NoError(t, err)
-
+			plugin.Stop()
 			testutil.RequireMetricsEqual(t, tt.expected, acc.GetTelegrafMetrics())
 		})
 	}
@@ -2659,9 +2655,7 @@ def apply(metric):
 				require.NoError(t, err)
 			}
 
-			err = plugin.Stop()
-			require.NoError(t, err)
-
+			plugin.Stop()
 			testutil.RequireMetricsEqual(t, tt.expected, acc.GetTelegrafMetrics())
 		})
 	}
@@ -2935,9 +2929,7 @@ func TestScript(t *testing.T) {
 				}
 			}
 
-			err = tt.plugin.Stop()
-			require.NoError(t, err)
-
+			tt.plugin.Stop()
 			testutil.RequireMetricsEqual(t, tt.expected, acc.GetTelegrafMetrics())
 		})
 	}
@@ -3245,6 +3237,29 @@ def apply(metric):
 				),
 			},
 		},
+		{
+			name: "filter by field value",
+			source: `
+def apply(metric):
+	match = metric.tags.get("bar") == "yeah" or metric.tags.get("tag_1") == "foo"
+	match = match and metric.fields.get("value_1") > 5 and metric.fields.get("value_2") < 3.5
+	if match:
+		return metric
+	return None
+`,
+			input: []telegraf.Metric{
+				testutil.MustMetric("cpu",
+					map[string]string{
+						"tag_1": "foo",
+					},
+					map[string]interface{}{
+						"value_1": 42,
+						"value_2": 3.1415,
+					},
+					time.Unix(0, 0),
+				),
+			},
+		},
 	}
 
 	for _, tt := range tests {
@@ -3267,8 +3282,7 @@ def apply(metric):
 				}
 			}
 
-			err = plugin.Stop()
-			require.NoError(b, err)
+			plugin.Stop()
 		})
 	}
 }
@@ -3309,9 +3323,7 @@ func TestAllScriptTestData(t *testing.T) {
 					}
 				}
 
-				err = plugin.Stop()
-				require.NoError(t, err)
-
+				plugin.Stop()
 				testutil.RequireMetricsEqual(t, outputMetrics, acc.GetTelegrafMetrics(), testutil.SortMetrics())
 			})
 			return nil
@@ -3363,7 +3375,7 @@ func parseErrorMessage(t *testing.T, lines []string, header string) string {
 	if startIdx == -1 {
 		return ""
 	}
-	require.True(t, startIdx < len(lines), fmt.Sprintf("Expected to find the error message after %q, but found none", header))
+	require.Less(t, startIdx, len(lines), fmt.Sprintf("Expected to find the error message after %q, but found none", header))
 	return strings.TrimLeft(lines[startIdx], "# ")
 }
 
