@@ -5,12 +5,13 @@ import (
 	"log"
 
 	"github.com/influxdata/telegraf"
+	"github.com/influxdata/telegraf/plugins/serializers"
 )
 
-type serializer struct {
-	HecRouting              bool
-	SplunkmetricMultiMetric bool
-	OmitEventTag            bool
+type Serializer struct {
+	HecRouting   bool `toml:"splunkmetric_hec_routing"`
+	MultiMetric  bool `toml:"splunkmetric_multimetric"`
+	OmitEventTag bool `toml:"splunkmetric_omit_event_tag"`
 }
 
 type CommonTags struct {
@@ -30,22 +31,11 @@ type HECTimeSeries struct {
 	Fields map[string]interface{} `json:"fields"`
 }
 
-// NewSerializer Setup our new serializer
-func NewSerializer(splunkmetricHecRouting bool, splunkmetricMultimetric bool, splunkmetricOmitEventTag bool) *serializer {
-	/*	Define output params */
-	s := &serializer{
-		HecRouting:              splunkmetricHecRouting,
-		SplunkmetricMultiMetric: splunkmetricMultimetric,
-		OmitEventTag:            splunkmetricOmitEventTag,
-	}
-	return s
-}
-
-func (s *serializer) Serialize(metric telegraf.Metric) ([]byte, error) {
+func (s *Serializer) Serialize(metric telegraf.Metric) ([]byte, error) {
 	return s.createObject(metric), nil
 }
 
-func (s *serializer) SerializeBatch(metrics []telegraf.Metric) ([]byte, error) {
+func (s *Serializer) SerializeBatch(metrics []telegraf.Metric) ([]byte, error) {
 	var serialized []byte
 
 	for _, metric := range metrics {
@@ -58,7 +48,7 @@ func (s *serializer) SerializeBatch(metrics []telegraf.Metric) ([]byte, error) {
 	return serialized, nil
 }
 
-func (s *serializer) createMulti(metric telegraf.Metric, dataGroup HECTimeSeries, commonTags CommonTags) (metricGroup []byte, err error) {
+func (s *Serializer) createMulti(metric telegraf.Metric, dataGroup HECTimeSeries, commonTags CommonTags) (metricGroup []byte, err error) {
 	/* When splunkmetric_multimetric is true, then we can write out multiple name=value pairs as part of the same
 	** event payload. This only works when the time, host, and dimensions are the same for every name=value pair
 	** in the timeseries data.
@@ -108,7 +98,7 @@ func (s *serializer) createMulti(metric telegraf.Metric, dataGroup HECTimeSeries
 	return metricGroup, nil
 }
 
-func (s *serializer) createSingle(metric telegraf.Metric, dataGroup HECTimeSeries, commonTags CommonTags) (metricGroup []byte, err error) {
+func (s *Serializer) createSingle(metric telegraf.Metric, dataGroup HECTimeSeries, commonTags CommonTags) (metricGroup []byte, err error) {
 	/* The default mode is to generate one JSON entity per metric (required for pre-8.0 Splunks)
 	**
 	** The format for single metric is 'nameOfMetric = valueOfMetric'
@@ -158,7 +148,7 @@ func (s *serializer) createSingle(metric telegraf.Metric, dataGroup HECTimeSerie
 	return metricGroup, nil
 }
 
-func (s *serializer) createObject(metric telegraf.Metric) (metricGroup []byte) {
+func (s *Serializer) createObject(metric telegraf.Metric) (metricGroup []byte) {
 	/*  Splunk supports one metric json object, and does _not_ support an array of JSON objects.
 	     ** Splunk has the following required names for the metric store:
 		 ** metric_name: The name of the metric
@@ -187,7 +177,7 @@ func (s *serializer) createObject(metric telegraf.Metric) (metricGroup []byte) {
 		}
 	}
 	commonTags.Time = float64(metric.Time().UnixNano()) / float64(1000000000)
-	switch s.SplunkmetricMultiMetric {
+	switch s.MultiMetric {
 	case true:
 		metricGroup, _ = s.createMulti(metric, dataGroup, commonTags)
 	default:
@@ -219,3 +209,20 @@ func verifyValue(v interface{}) (value interface{}, valid bool) {
 	}
 	return value, valid
 }
+
+func init() {
+	serializers.Add("splunkmetric",
+		func() serializers.Serializer {
+			return &Serializer{}
+		},
+	)
+}
+
+// InitFromConfig is a compatibility function to construct the parser the old way
+func (s *Serializer) InitFromConfig(cfg *serializers.Config) error {
+	s.HecRouting = cfg.HecRouting
+	s.MultiMetric = cfg.SplunkmetricMultiMetric
+	s.OmitEventTag = cfg.SplunkmetricOmitEventTag
+
+	return nil
+}
